==> slrn-0.8.7.1-3.tar.gz: slrn-0.8.7.1/src/art.h <==
extern int slrn_article_mode (char *, Slrn_Range_Type *, int);
extern void slrn_init_article_keymap (void);
extern SLKeyMap_List_Type *Slrn_Article_Keymap;
extern char *Slrn_Quote_String;
extern char *Slrn_Save_Directory;
extern int Slrn_Show_Author;
extern int Slrn_Startup_With_Article;
extern int Slrn_Show_Thread_Subject;
extern int Slrn_Query_Next_Article;
extern int Slrn_Query_Next_Group;
extern int Slrn_Auto_CC_To_Poster;
extern int Slrn_Score_After_XOver;
extern int Slrn_Use_Tmpdir;
extern int Slrn_Sorting_Mode;
extern int Slrn_Threads_Visible;
extern int Slrn_Wrap_Mode;
extern int Slrn_Use_Header_Numbers;
typedef struct Slrn_Header_Type
{
   struct Slrn_Header_Type *real_next, *real_prev;
   struct Slrn_Header_Type *next, *prev;  /* threaded next/prev */
   struct Slrn_Header_Type *parent, *child, *sister;  /* threaded relatives */
   struct Slrn_Header_Type *hash_next;  /* next in hash table */
   unsigned int num_children;
   unsigned long hash;		       /* based on msgid */
   int number;			       /* server number */
   int lines;
   char *subject;			       /* malloced */
   char *from;			       /* pointers to above space */
   char *date;
   char *msgid;
   char *refs;
   char *xref;
   char *realname;		       /* NOT Null terminated */
   int realname_len;
   unsigned int flags;
#define HEADER_READ 0x1
#define HEADER_HIDDEN 0x2
#define HEADER_NTAGGED 0x8
#define HEADER_TAGGED 0x10
#define HEADER_HIGH_SCORE 0x20
#define HEADER_LOW_SCORE 0x40
#define FAKE_PARENT 0x80
#define FAKE_CHILDREN 0x100
#define FAKE_HEADER_HIGH_SCORE 0x200
   unsigned int tag_number;
#define MAX_TREE_SIZE 24
   unsigned char tree[MAX_TREE_SIZE];
} Slrn_Header_Type;

typedef struct Slrn_Article_Line_Type
{
   struct Slrn_Article_Line_Type *next, *prev;
   char *buf;
   unsigned int flags;
#define HEADER_LINE	1
#define HIDDEN_LINE	2
#define QUOTE_LINE	4
#define SIGNATURE_LINE	8
#define WRAPPED_LINE	0x10
}
Slrn_Article_Line_Type;

extern Slrn_Article_Line_Type *Slrn_Article_Lines;

==> slrn_0.8.8.4.orig.tar.gz: slrn-0.8.8.4.orig/src/art.h <==
extern int slrn_article_mode (char *, Slrn_Range_Type *, int, int);
extern void slrn_init_article_keymap (void);
extern SLKeyMap_List_Type *Slrn_Article_Keymap;
extern char *Slrn_Quote_String;
extern char *Slrn_Save_Directory;
extern int Slrn_Show_Author;
extern int Slrn_Startup_With_Article;
extern int Slrn_Show_Thread_Subject;
extern int Slrn_Query_Next_Article;
extern int Slrn_Query_Next_Group;
extern int Slrn_Auto_CC_To_Poster;
extern int Slrn_Score_After_XOver;
extern int Slrn_Use_Tmpdir;
extern int Slrn_Sorting_Mode;
extern int Slrn_Threads_Visible;
extern int Slrn_Wrap_Mode;
extern int Slrn_Use_Header_Numbers;
extern int Slrn_Reads_Per_Update;
extern char *Slrn_X_Browser;
extern char *Slrn_NonX_Browser;
#if SLRN_HAS_SPOILERS
extern int Slrn_Spoiler_Char;
#endif
extern int Slrn_Sig_Is_End_Of_Article;

typedef struct Slrn_Header_Type
{
   struct Slrn_Header_Type *real_next, *real_prev;
   struct Slrn_Header_Type *next, *prev;  /* threaded next/prev */
   struct Slrn_Header_Type *parent, *child, *sister;  /* threaded relatives */
   struct Slrn_Header_Type *hash_next;  /* next in hash table */
   unsigned int num_children;
   unsigned long hash;		       /* based on msgid */
   int number;			       /* server number */
   int lines;
   char *subject;			       /* malloced */
   char *from;			       /* pointers to above space */
   char *date;
   char *msgid;
   char *refs;
   char *xref;
   char *realname;		       /* NOT Null terminated */
   int realname_len;
   unsigned int flags;
#define HEADER_READ 0x1
#define HEADER_HIDDEN 0x2
#define HEADER_NTAGGED 0x8
#define HEADER_TAGGED 0x10
#define HEADER_HIGH_SCORE 0x20
#define HEADER_LOW_SCORE 0x40
#define FAKE_PARENT 0x80
#define FAKE_CHILDREN 0x100
#define FAKE_HEADER_HIGH_SCORE 0x200
   unsigned int tag_number;
#define MAX_TREE_SIZE 24
   unsigned char tree[MAX_TREE_SIZE];
} Slrn_Header_Type;

typedef struct Slrn_Article_Line_Type
{
   struct Slrn_Article_Line_Type *next, *prev;
   char *buf;
   unsigned int flags;
#define HEADER_LINE	1
#define HIDDEN_LINE	2
#define QUOTE_LINE	4
#define SIGNATURE_LINE	8
#define WRAPPED_LINE	0x10
#if SLRN_HAS_SPOILERS
# define SPOILER_LINE	0x20
#endif
}
Slrn_Article_Line_Type;

extern Slrn_Article_Line_Type *Slrn_Article_Lines;

extern SLRegexp_Type *Slrn_Ignore_Quote_Regexp[];
